@@ -1,7 +1,7 @@
 loglik.plot<-function(X,dist=c("norm","poi","bin","exp","custom"),plot.likfunc=TRUE,parameter=NULL,func=NULL,poss=NULL,plot.density=TRUE,plot.calc=FALSE,xlab=NULL,ylab=NULL,conv=0.01,anim=TRUE,interval=0.01,...){
 if(dist=="norm")loglik.norm.plot(X=X,parameter=parameter,poss=poss,plot.likfunc=plot.likfunc,plot.density=plot.density,plot.calc=plot.calc,xlab=xlab,ylab=ylab,conv=conv,anim=anim,interval=interval,...=...)
 if(dist=="poi")loglik.pois.plot(X=X,poss=poss,plot.likfunc=plot.likfunc,plot.density=plot.density,plot.calc=plot.calc,xlab=xlab,ylab=ylab,conv=conv,anim=anim,interval=interval,...=...)
-if(dist=="bin")loglik.binom.plot(X=X,poss=poss,xlab=xlab,ylab=ylab,conv=conv,anim=anim,interval=interval,...=...)
+if(dist=="bin")loglik.binom.plot(X=X,poss=poss,plot.likfunc=plot.likfunc,plot.density=plot.density,xlab=xlab,ylab=ylab,conv=conv,anim=anim,interval=interval,...=...)
 if(dist=="exp")loglik.exp.plot(X=X,poss=poss,plot.likfunc=plot.likfunc,plot.density=plot.density,plot.calc=plot.calc,xlab=xlab,ylab=ylab,conv=conv,anim=anim,interval=interval,...=...)
 if(dist=="custom")loglik.custom.plot(X=X,func=func,poss=poss,anim=anim,interval=interval,xlab=xlab,ylab=ylab,...=...)
 }
@@ -191,39 +191,62 @@ Max.lik<-log(prod(dpois(X,mean(X))))
 ############%%%%%% BINOMIAL %%%%%%################
 ##################################################
 
-loglik.binom.plot<-function(X,poss=NULL,xlab=NULL,ylab=NULL,anim=TRUE,interval=0.01,conv=0.01,...){
+loglik.binom.plot<-function(X,poss=NULL,xlab=NULL,ylab=NULL,plot.likfunc=TRUE,plot.density=TRUE,conv=0.01,anim=TRUE,interval=0.01,...){
 possibilities<-poss
 if(is.null(poss)) {possibilities<-seq(max(0,mean(X)-2*sd(X)),min(1,mean(X)+sd(X)*2),conv)
 logl<-seq(min(possibilities),max(possibilities),conv)}
   if(!is.null(poss)) if(!is.null(poss))logl<-poss
     for(i in 1:length(possibilities)){
     {
-    logl[i]<-log(prod(dbinom(sum(X),size=nrow(as.matrix(X)),prob=possibilities[i])))}
+    logl[i]<-log(prod(dbinom(sum(X),size=length(X),prob=possibilities[i])))}
     }
 max.p<-ifelse(is.null(poss),mean(X),possibilities[logl==max(logl)][1])
 MLE<-mean(X)
-Max.lik<-log(prod(dbinom(X,sum(X),mean(X))))
+Max.lik<-log(prod(dbinom(sum(X),length(X),mean(X))))
 
 ##No Animation
       if(anim==FALSE){
-          plot(possibilities,logl,type="l",ylab=ifelse(is.null(ylab), "Binomial Log-likelihood function", ylab),
-          xlab=ifelse(is.null(xlab),"Estimates for p",xlab),...)
-          legend("topright",legend=bquote(paste("ML est. = ",.(MLE))),cex=.9,bty="n")
-          abline(v=mean(X),lty=2,col=2)
+          if(plot.likfunc==TRUE&plot.density==TRUE)dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.9)
+          if(plot.likfunc==TRUE){
+              plot(possibilities,logl,type="l",ylab=ifelse(is.null(ylab), "Binomial Log-likelihood function", ylab),
+              xlab=ifelse(is.null(xlab),expression(paste("Estimates for ", italic(p))),xlab),...)
+              legend("topright",legend=bquote(paste("ML est. = ",.(MLE))),cex=.9,bty="n")
+              abline(v=mean(X),lty=2,col=2)
           }
-      
+          if(plot.density==TRUE){
+              plot(sum(X),dbinom(sum(X),length(X),mean(X)),xlab= "x",ylab="f(x)",type="l")
+              legend("topright",legend=c(paste("X~BIN(",bquote(.(round(mean(X),3))),")",sep=""),
+              paste("Loglik = ",bquote(.(round(Max.lik,2))))),bty="n",cex=.9)
+              legend("topleft",col=2,lty=2,legend="Obs. density",bty="n",cex=.9)
+              segments(sum(X),0,sum(X),dbinom(sum(X),length(X),mean(X)),lty=2,col=2)
+              points(sum(X),dbinom(sum(X),length(X),mean(X)),pch=16,cex=.9)
+          }
+      } 
   ##Animation
       if(anim==TRUE){
         nm<-which(logl==max(logl))[1]
+      if(plot.likfunc==TRUE&plot.density==TRUE)dev.new(height=4,width=8);par(mfrow=c(1,2),mar=c(4.4,4.5,1,0.5),cex=.9)
            for(i in 1:(nm-1)){
-                plot(possibilities,logl,type="n",ylab=ifelse(is.null(ylab),"Binomial Log-likelihood function",ylab), 
-                xlab=ifelse(is.null(xlab),"Estimates for p",xlab),...)
-                arrows(possibilities[i],logl[i],possibilities[i+1],logl[i+1],col=2,length=.15,lwd=1)
-                points(possibilities[1:i],logl[1:i],lty=2,col=2,lwd=1,type="l")
-                    if(i == (nm-1)){points(possibilities,logl,type="l")
-                        abline(v=mean(X),lty=2,col=2)
-                        legend("topright",legend=bquote(paste("ML est. = ",.(MLE))),cex=.9,bty="n")}
-               Sys.sleep(interval)
+               if(plot.likfunc==TRUE){     
+                    plot(possibilities,logl,type="n",ylab=ifelse(is.null(ylab),"Binomial Log-likelihood function",ylab), 
+                    xlab=ifelse(is.null(xlab),expression(paste("Estimates for ", italic(p))),xlab),...)
+                    arrows(possibilities[i],logl[i],possibilities[i+1],logl[i+1],col=2,length=.15,lwd=1)
+                    points(possibilities[1:i],logl[1:i],lty=2,col=2,lwd=1,type="l")
+                        if(i == (nm-1)){points(possibilities,logl,type="l")
+                            abline(v=mean(X),lty=2,col=2)
+                            legend("topright",legend=bquote(paste("ML est. = ",.(MLE))),cex=.9,bty="n")}
+              }
+              if(plot.density==TRUE){
+                    plot(sum(X),dbinom(sum(X),length(X),possibilities[i]),xlab= "x",ylab="f(x)",type="n",ylim=c(0,exp(Max.lik)))
+                    segments(x0=sum(X),y0=0,x1=sum(X),y1=dbinom(sum(X),length(X),possibilities[i]),col=2,lty=2)
+                    points(sum(X),dbinom(sum(X),length(X),possibilities[i]),pch=16)
+                        if(i != (nm-1)){legend("topright",legend=c(as.expression(bquote(paste(italic(p), " = ",.(round(possibilities[i],2))))),
+                        as.expression(bquote(paste("Loglik = ", .(round(logl[i],2)))))),bty="n",cex=.9)
+                        }
+                        if(i == (nm-1)){legend("topright",legend=c(as.expression(bquote(paste(italic(p), " = ",.(MLE)))),as.expression(bquote(paste("Loglik = ",
+                        .(round(Max.lik,2)))))),bty="n",cex=.9)}
+              }
+           Sys.sleep(interval)
           }
       }
   }
